@@ -2,6 +2,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 
 ASSET_MANAGER_TYPES = {'Accredited Investor', 'Bank', 'Broker', 'Corporate Treasury', 'Family Office',
-                       'Fund Administrator', 'Fund Manager', 'Hedge Fund', 'Private Equity', 'Retail',
-                       'Venture Capital'}
+                       'Fund Administrator', 'Fund Manager', 'Hedge Fund', 'Individual', 'Private Equity',
+                       'Venture Capital', 'Data Provider'}
 RELATIONSHIP_TYPES = {'Administrator', 'External', 'Front Office', 'Employee'}
+ACCOUNT_TYPES = {'Internal', 'Test', 'Basic', 'Professional'}
\ No newline at end of file
