@@ -2,17 +2,17 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 import logging
 
-from amaascore.config import ENDPOINTS
+from amaascore.config import ENVIRONMENT
 from amaascore.core.interface import Interface
 from amaascore.corporate_actions.utils import json_to_corporate_action
 
 
 class CorporateActionsInterface(Interface):
 
-    def __init__(self, logger=None):
-        endpoint = ENDPOINTS.get('corporate_actions')
+    def __init__(self, environment=ENVIRONMENT, logger=None, endpoint=None, username=None, password=None):
         self.logger = logger or logging.getLogger(__name__)
-        super(CorporateActionsInterface, self).__init__(endpoint=endpoint)
+        super(CorporateActionsInterface, self).__init__(endpoint=endpoint, endpoint_type='corporate_actions',
+                                                        environment=environment, username=username, password=password)
 
     def new(self, corporate_action):
         self.logger.info('New Corporate Action - Asset Manager: %s - Corporate Action ID: %s',
@@ -43,10 +43,12 @@ class CorporateActionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def retrieve(self, asset_manager_id, corporate_action_id):
+    def retrieve(self, asset_manager_id, corporate_action_id, version=None):
         self.logger.info('Retrieve Corporate Action - Asset Manager: %s - Corporate Action ID: %s', asset_manager_id,
                          corporate_action_id)
         url = '%s/corporate-actions/%s/%s' % (self.endpoint, asset_manager_id, corporate_action_id)
+        if version:
+            url += '?version=%d' % int(version)
         response = self.session.get(url)
         if response.ok:
             self.logger.info('Successfully Retrieved Corporate Action - Asset Manager: %s - Corporate Action ID: %s',
@@ -75,9 +77,9 @@ class CorporateActionsInterface(Interface):
         search_params = {}
         # Potentially roll this into a loop through args rather than explicitly named - depends on additional validation
         if asset_manager_ids:
-            search_params['asset_manager_ids'] = asset_manager_ids
+            search_params['asset_manager_ids'] = ','.join([str(amid) for amid in asset_manager_ids])
         if corporate_action_ids:
-            search_params['asset_ids'] = corporate_action_ids
+            search_params['asset_ids'] = ','.join(corporate_action_ids)
         url = self.endpoint + '/corporate-actions'
         response = self.session.get(url, params=search_params)
         if response.ok:
@@ -99,3 +101,18 @@ class CorporateActionsInterface(Interface):
         else:
             self.logger.error(response.text)
             response.raise_for_status()
+
+    def clear(self, asset_manager_id):
+        """ This method deletes all the data for an asset_manager_id.
+            It should be used with extreme caution.  In production it
+            is almost always better to Inactivate rather than delete. """
+        self.logger.info('Clear Corporate Actions - Asset Manager: %s', asset_manager_id)
+        url = '%s/clear/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.delete(url)
+        if response.ok:
+            count = response.json().get('count', 'Unknown')
+            self.logger.info('Deleted %s Corporate Actions.', count)
+            return count
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
